@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2017 Montel Laurent <montel@kde.org>
+  Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -16,11 +16,10 @@
 */
 
 #include "logactivitieswidget.h"
-#include <KLocalizedString>
-#include <QPlainTextEdit>
 #include <QVBoxLayout>
 #include <KPIMTextEdit/PlainTextEditorWidget>
 #include <KPIMTextEdit/PlainTextEditor>
+#include <QDebug>
 using namespace PimCommon;
 
 LogActivitiesWidget::LogActivitiesWidget(QWidget *parent)
@@ -39,7 +38,7 @@ LogActivitiesWidget::LogActivitiesWidget(QWidget *parent)
 
 LogActivitiesWidget::~LogActivitiesWidget()
 {
-
+    disconnect(mLog->editor(), &KPIMTextEdit::PlainTextEditor::textChanged, this, &LogActivitiesWidget::slotTextChanged);
 }
 
 void LogActivitiesWidget::slotTextChanged()
