@@ -32,7 +32,7 @@
 #include "collectionaclwidget.h"
 #include "aclmanager.h"
 #include "imapaclattribute.h"
-#include <collection.h>
+#include <AkonadiCore/Collection>
 #include <KLocalizedString>
 #include <QHBoxLayout>
 
@@ -42,16 +42,15 @@ class PimCommon::CollectionAclPagePrivate
 {
 public:
     CollectionAclPagePrivate()
-        : mCollectionAclWidget(nullptr)
     {
-
     }
-    CollectionAclWidget *mCollectionAclWidget;
+
+    CollectionAclWidget *mCollectionAclWidget = nullptr;
 };
 
 CollectionAclPage::CollectionAclPage(QWidget *parent)
-    : CollectionPropertiesPage(parent),
-      d(new PimCommon::CollectionAclPagePrivate)
+    : CollectionPropertiesPage(parent)
+    , d(new PimCommon::CollectionAclPagePrivate)
 {
     setObjectName(QStringLiteral("PimCommon::CollectionAclPage"));
 
@@ -91,4 +90,3 @@ void CollectionAclPage::save(Akonadi::Collection &collection)
     PimCommon::ImapAclAttribute *attribute = d->mCollectionAclWidget->aclManager()->collection().attribute<PimCommon::ImapAclAttribute>();
     collection.addAttribute(attribute->clone());
 }
-
