@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,8 +20,7 @@
 
 #include <QWidget>
 class QCheckBox;
-namespace PimCommon
-{
+namespace PimCommon {
 class AclManager;
 class CollectionAclWidget : public QWidget
 {
@@ -39,8 +38,8 @@ private Q_SLOTS:
     void slotCollectionCanBeAdministrated(bool b);
 
 private:
-    PimCommon::AclManager *mAclManager;
-    QCheckBox *mRecursiveChk;
+    PimCommon::AclManager *mAclManager = nullptr;
+    QCheckBox *mRecursiveChk = nullptr;
 };
 }
 
