@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -24,8 +24,7 @@
 #include "pimcommonakonadi_export.h"
 #include <QWidget>
 
-namespace PimCommon
-{
+namespace PimCommon {
 class IncidencesForWidgetPrivate;
 class PIMCOMMONAKONADI_EXPORT IncidencesForWidget : public QWidget
 {
