@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,16 +24,15 @@ class PimCommon::GenericPluginInterfacePrivate
 public:
     GenericPluginInterfacePrivate()
     {
-
     }
-    ActionType actionType;
+
+    QVector<ActionType> actionTypes;
 };
 
 GenericPluginInterface::GenericPluginInterface(QObject *parent)
-    : AbstractGenericPluginInterface(parent),
-      d(new GenericPluginInterfacePrivate)
+    : AbstractGenericPluginInterface(parent)
+    , d(new GenericPluginInterfacePrivate)
 {
-
 }
 
 GenericPluginInterface::~GenericPluginInterface()
@@ -41,14 +40,20 @@ GenericPluginInterface::~GenericPluginInterface()
     delete d;
 }
 
-void GenericPluginInterface::setActionType(const ActionType &type)
+void GenericPluginInterface::setActionTypes(const QVector<ActionType> &type)
 {
-    d->actionType = type;
+    d->actionTypes = type;
 }
 
-ActionType GenericPluginInterface::actionType() const
+void GenericPluginInterface::addActionType(const ActionType &type)
 {
-    return d->actionType;
+    //TODO check already existance ?
+    d->actionTypes.append(type);
+}
+
+QVector<ActionType> GenericPluginInterface::actionTypes() const
+{
+    return d->actionTypes;
 }
 
 void GenericPluginInterface::updateActions(int numberOfSelectedItems, int numberOfSelectedCollections)
@@ -83,8 +88,8 @@ PimCommon::GenericPluginInterface::RequireTypes GenericPluginInterface::requires
 }
 
 ActionType::ActionType(QAction *action, ActionType::Type type)
-    : mAction(action),
-      mType(type)
+    : mAction(action)
+    , mType(type)
 {
 }
 
